@@ -1,7 +1,7 @@
 # Copyright (c) 2007 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
-# $Id: CNic.pm,v 1.47 2007/07/24 11:35:59 gavin Exp $
+# $Id: CNic.pm,v 1.49 2008/02/05 11:07:48 gavin Exp $
 package WWW::CNic;
 use LWP;
 use LWP::ConnCache;
@@ -11,7 +11,7 @@ use Digest::MD5 qw(md5_hex);
 use vars qw($VERSION $CONNECTION_CACHE);
 use strict;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 =pod
 
@@ -344,18 +344,21 @@ sub _register {
 		$dns = 'defaults';
 		$dns_param = 'dns'
 	}
-	my %params = 	(
-				user		=> $self->{_username},
-				password	=> $self->_crypt_md5($self->{_password}),
-				test		=> $self->{_test},
-				domain		=> $domain,
-				suffix		=> $suffix,
-				registrant	=> $self->{_params}->{registrant},
-				chandle		=> $chandle,
-				thandle		=> $thandle,
-				period		=> $self->{_params}->{period},
-				$dns_param	=> $dns,
-			);
+	my %params = (
+		user		=> $self->{_username},
+		password	=> $self->_crypt_md5($self->{_password}),
+		test		=> $self->{_test},
+		domain		=> $domain,
+		suffix		=> $suffix,
+		registrant	=> $self->{_params}->{registrant},
+		chandle		=> $chandle,
+		thandle		=> $thandle,
+		period		=> $self->{_params}->{period},
+		$dns_param	=> $dns,
+	);
+
+	$params{url} = $self->{_params}->{url} if ($self->{_params}->{url} ne '');
+
 	my $POST_URL = $self->{_base}.'/'.($args{idn} == 1 ? 'register_idn' : 'register');
 	my $req = HTTP::Request->new(POST => $POST_URL);
 	$req->content_type('application/x-www-form-urlencoded');
@@ -411,12 +414,15 @@ sub _modify {
 	die("Missing domain name") if $self->{_domain} eq '';
 	die("Missing username") if $self->{_username} eq '';
 	die("Missing password") if $self->{_password} eq '';
-	my %params = 	(
-				user		=> $self->{_username},
-				password	=> $self->_crypt_md5($self->{_password}),
-				test		=> $self->{_test},
-				domain		=> $self->{_domain},
-			);
+	my %params = (
+		user		=> $self->{_username},
+		password	=> $self->_crypt_md5($self->{_password}),
+		test		=> $self->{_test},
+		domain		=> $self->{_domain},
+	);
+
+	$params{url} = $self->{_params}->{url} if ($self->{_params}->{url} ne '');
+
 	if (defined($self->{_params}->{chandle})) {
 		$params{chandle} = (ref($self->{_params}->{chandle}) eq 'HASH' ? $self->_build_handle_string($self->{_params}->{chandle}) : $self->{_params}->{chandle});
 	}
@@ -846,9 +852,9 @@ sub _salt {
 
 sub _crypt_md5 {
 	my ($self, $str) = @_;
-	### special hack: Mac OS X doesn't support MD5 in the crypt() function
+	### special hack: Mac OS X and Windows don't support MD5 in the crypt() function
 	### so use plaintext passwords:
-	if ($^O eq 'darwin') {
+	if ($^O eq 'darwin' || $^O eq 'MSWin32') {
 		return 'plain:'.$str;
 
 	} else {
