@@ -1,7 +1,7 @@
 # Copyright (c) 2007 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
-# $Id: Cookbook.pm,v 1.41 2007/07/24 11:35:59 gavin Exp $
+# $Id: Cookbook.pm,v 1.42 2008/02/05 11:07:48 gavin Exp $
 
 package WWW::CNic::Cookbook;
 use vars qw($VERSION);
@@ -313,10 +313,17 @@ We recommend that you enable SSL when making registration and modification reque
 		registrant	=> 'Example, Inc',
 		chandle		=> $chandle,
 		thandle		=> $thandle,
-		dns		=> ['ns0.example.com', 'ns1.example.com'],
 		period		=> 2,
 	);
 
+	# Set DNS servers
+
+	$query->set(dns => ['ns0.example.com', 'ns1.example.com']);
+
+	# OR
+
+	$query->set(url => 'http://www.example.com/');
+
 	my $response = $query->execute;
 
 	if ($response->is_success) {
@@ -352,14 +359,18 @@ C<thandle> - the Technical Handle. This may take two values. It can be a scalar
 C<dns> - the DNS servers for the domain. This can either be an anonymous array of DNS hostnames, or a reference to hash such as that below:
 
 	my $dns = {
-		'ns0.centralic.net' => '192.168.1.1',
-		'ns1.centralic.net' => '192.168.1.2',
+		'ns0.example.com' => '192.168.1.1',
+		'ns1.example.com' => '192.168.1.2',
 	};
 
-If you have specified default DNS servers using the Reseller Console you can set C<$dns> to be 'C<defaults>' and the system will use these.
+If you have specified default DNS servers using the Registrar Console you can set C<$dns> to be 'C<defaults>' and the system will use these.
 
 =item 5
 
+C<url> - if this parameter is provided and is not empty, it will be used to set a simple web forwarding for the domain I<instead of any DNS servers provided>.
+
+=item 6
+
 C<period> - the registration period for the domain name. This is an integer number of years and must be between 2 and 10, or 100. If this field is omitted the domain will be registered for 2 years.
 
 =back
@@ -390,6 +401,7 @@ You can use C<WWW::CNic> to do real-time modification of a domain. The procedure
 			drop	=> 'all',
 			add	=> ['ns0.example.com',   'ns1.example.com'],
 		}
+		url	=> 'drop',
 	);
 
 	my $response = $query->execute;
@@ -416,6 +428,14 @@ C<dns> must be an anonymous hash (or a reference to a hash) with two keys: C<add
 
 B<NB>: In addition to specifying a handle ID in the C<thandle> field, it is also possible to use an anonymous hash to supply the details of a new handle. However this usage is not recommended.
 
+=item 3
+
+C<url> is an optional element containing a new URL to which to forward the domain. If this parameter is set, then the C<dns> parameter is ignored, and any existing DNS servers are removed from the domain.
+
+If this parameter contains the special keyword C<'drop'> then the web forwarding will be removed, and the domain will be 'parked'.
+
+=back
+
 =head2 Modifying a Handle
 
 When a handle is created by the C<create_handle> or C<register> commands, or via other interfaces such as the Reseller Console, it is associated with your account. This allows you to update the contact details for that handle.
